@@ -10,6 +10,9 @@ __author__ = 'TROUVERIE Joachim'
 
 import os.path as op
 from os import makedirs, symlink
+
+from utils import merge_default_config
+
 from flask import Flask
 from flask.ext.flatpages import FlatPages
 from flask.ext.codemirror import CodeMirror
@@ -27,6 +30,9 @@ if op.exists(path) :
 else :
     app.config.from_pyfile('default_settings.py')
 
+# add constants in case of update
+merge_default_config(app)
+
 # create path if not exists
 path =  op.join(op.dirname(__file__), 'content')
 if not op.exists(path) :
