@@ -230,7 +230,7 @@ def contents() :
         content = [c for c in contents if c.path == path][0]
         # delete
         if delete :
-            contents.delete(content)
+            contents.remove(content)
             content.delete()
             delete_document(content)
         # publish
