@@ -13,15 +13,17 @@ from clize import clize, run
 from datetime import datetime
 from urlparse import urljoin
 from werkzeug.contrib.atom import AtomFeed
+
+from microbe import app, pages, babel
+from models import Content, Links
+from forms import CommentForm, SearchForm
+from utils import get_objects_for_page, create_pagination
+from search import search_query, init_index
+
 from flask import g, request, abort, session
-from flask.ext.paginate import Pagination
 from flask.ext.babel import format_datetime, lazy_gettext
 from flask.ext.themes2 import render_theme_template
-from microbe import app, pages, babel
-from models import Content 
-from forms import CommentForm, SearchForm
-from utils import get_objects_for_page
-from search import search_query, init_index
+
 
 def render(template, **context):
     """
@@ -31,18 +33,6 @@ def render(template, **context):
     return render_theme_template(theme, template, **context)
 
 
-def create_pagination(page, per_page, objects) :
-    """
-    Create pagination object
-    """
-    return Pagination(page = page, 
-                      total = len(objects), 
-                      search = False,
-                      per_page = per_page,
-                      css_framework='foundation')
-
-
-
 @app.errorhandler(404)
 def page_not_found(e):
     """
@@ -85,6 +75,9 @@ def before_request() :
     # static pages
     g.static_pages = [c for c in contents if c.content_type == 'pages'
                      and not c.draft]
+    # links
+    g.links = Links.get_all()
+    # search form
     if not hasattr(g, 'search_form') : 
         g.search_form = SearchForm()
 
@@ -102,7 +95,7 @@ def index():
     per_page = app.config[u'PAGINATION']    
     pagination = create_pagination(page, per_page, g.posts)
     # get content for current page
-    displayed = get_objects_for_page(g.posts, page, per_page)
+    displayed = get_objects_for_page(page, per_page, g.posts)
     # override page to have summary
     return render('index.html', pages=displayed, pagination=pagination)
 
@@ -121,8 +114,8 @@ def page(path):
     # form management
     if form and form.validate_on_submit() :
         author = form.name.data
-        content = form.content.data
-        page.add_comment(author, content)
+        body = form.content.data
+        content.add_comment(author, body)
     return render('page.html', page = content, form = form)
 
 
@@ -140,7 +133,7 @@ def category(category) :
     per_page = app.config[u'PAGINATION']    
     pagination = create_pagination(page, per_page, posts)
     # get content for current page
-    displayed = get_objects_for_page(posts, page, per_page)
+    displayed = get_objects_for_page(page, per_page, posts)
     return render('index.html', title = category, pages = displayed,
             pagination = pagination)
 
@@ -159,7 +152,7 @@ def tag(tag) :
     per_page = app.config[u'PAGINATION']    
     pagination = create_pagination(page, per_page, posts)
     # get content for current page
-    displayed = get_objects_for_page(posts, page, per_page)
+    displayed = get_objects_for_page(page, per_page, posts)
     return render('index.html', title = tag, pages = displayed,
             pagination = pagination)
 
@@ -183,7 +176,7 @@ def archives() :
     per_page = 10   
     pagination = create_pagination(page, per_page, sorted_pages)
     # get content for current page
-    displayed = get_objects_for_page(sorted_pages, page, per_page)
+    displayed = get_objects_for_page(page, per_page, sorted_pages)
     return render('archive.html',  pages = displayed, 
             pagination = pagination)
 
@@ -211,7 +204,7 @@ def search() :
     per_page = 20    
     pagination = create_pagination(page, per_page, sorted_contents)
     # get content for current page
-    displayed = get_objects_for_page(sorted_contents, page, per_page)
+    displayed = get_objects_for_page(page, per_page, sorted_contents)
     return render('index.html', title = query, pages = displayed,
             pagination = pagination)
 
